dayOfMonth

# XMLRésuméLibrary: User Guide

date | Element Reference | degree

## Name

dayOfMonth — An ordinal day of the month

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

Represents a specific day in a month. Its value is numeric; the first day of the month is written `1`, the fifteenth `15`, etc.

### Parents

`dayOfMonth` may be contained in these elements: `date`

## Examples

For examples, see `date`.

date | Element Reference | degree